@@ -12,7 +12,6 @@
 #include "config.h"
 #endif
 
-#include <algorithm>
 #include <cmath>
 #include <cstdio>
 
@@ -191,9 +190,10 @@ void pfb_clock_sync_ccf_impl::update_gains()
     d_beta = (4 * d_loop_bw * d_loop_bw) / denom;
 }
 
-void pfb_clock_sync_ccf_impl::set_taps(const std::vector<float>& newtaps,
-                                       std::vector<std::vector<float>>& ourtaps,
-                                       std::vector<kernel::fir_filter_ccf>& ourfilter)
+void pfb_clock_sync_ccf_impl::set_taps(
+    const std::vector<float>& newtaps,
+    std::vector<std::vector<float>>& ourtaps,
+    std::vector<filter::kernel::fir_filter_ccf>& ourfilter)
 {
     int i, j;
 
@@ -331,7 +331,7 @@ int pfb_clock_sync_ccf_impl::general_work(int noutput_items,
                                           gr_vector_const_void_star& input_items,
                                           gr_vector_void_star& output_items)
 {
-    gr_complex* in = (gr_complex*)input_items[0];
+    const gr_complex* in = (const gr_complex*)input_items[0];
     gr_complex* out = (gr_complex*)output_items[0];
 
     if (d_updated) {
